@@ -16,10 +16,14 @@ from typeguard import check_type
 from ._jsii import *
 
 __all__ = [
+    "env",
     "stacks",
+    "utils",
 ]
 
 publication.publish()
 
 # Loading modules to ensure their types are registered with the jsii runtime library
+from . import env
 from . import stacks
+from . import utils
